<?php
namespace Cdt;

Class Cdt{
	private $pdo;

	public function __construct($pdo){
		$this->pdo = $pdo;
	}


	/**
	 * Récupérer les classes cdt
	 * 
	 * @return array $classes 	les classes de cdt
	 */
	function getClassesCdt(){
		$req = $this->pdo->prepare('SELECT ID_classe, nom_classe, code_classe FROM cdt_classe ORDER BY code_classe ASC');
		if(!$req->execute())
			die('Une erreur s\'est produite. Veuillez recommencer' . $req->errorInfo());

		$classes['ID_classe'] = array();
		$classes['nom_classe'] = array();
		$classes['code_classe'] = array();

		while ($d = $req->fetch(\PDO::FETCH_OBJ)) {
			array_push($classes['ID_classe'], $d->ID_classe);
			array_push($classes['nom_classe'], $d->nom_classe);
			array_push($classes['code_classe'], $d->code_classe);
		}

		return $classes;
	}


	/**
	 * Récupérer les élèves
	 * 
	 * @return array $eleves    la liste des élèves dans cdt
	 */
	function getEleves(){
		$eleves = $this->pdo->query('select * from ele_liste');

		return $eleves->fetchAll();
	}


	/**
	 * Met à jour le code_classe des classes cdt qui existent dans le ldap
	 * 
	 * @param array $code_classes    les classes à mettre à jour dans cdt
	 * @return void
	 */
	function updateCdt($code_classes){
		foreach ($code_classes as $v) {
			if(!empty($v) && (isset($v))){
				if(!$this->classe_exists($v)){
					$req = $this->pdo->prepare('UPDATE cdt_classe SET code_classe=:code_classe WHERE nom_classe=:code_classe AND code_classe IS NULL OR code_classe=""');
					$req->bindParam(':code_classe', $v);

					if(!$req->execute()){
						die('Erreur lors de la mise à jour. Veuillez recommencer.');
					}
				}
			}
		}

		// récupérer les enregistrements qui n'ont pas été mis à jours
		$req = $this->pdo->query('SELECT ID_classe FROM cdt_classe WHERE code_classe IS NULL OR code_classe=""');
		$req->fetch();
		if($req->rowCount() > 0)
			return false;

		return true;
	}


	/**
	 * Éditer une classe cdt
	 * 
	 * @param string $code_classe   le code de la classe
	 * @param int $ID_classe    l'id de la classe
	 * @return void
	 */
	function associate($code_classe, $ID_classe){
		if(!empty($ID_classe) && isset($ID_classe)){
			if(!$this->code_classe_exists($code_classe)){
				$req = $this->pdo->prepare('UPDATE cdt_classe SET code_classe=:code_classe WHERE ID_classe=:ID_classe');
				$req->bindParam(':code_classe', $code_classe);
				$req->bindParam(':ID_classe', $ID_classe, \PDO::PARAM_INT);

				if(!$req->execute()){
					die('Erreur lors de la mise à jour de la classe. Veuillez recommencer.');
				}

				echo json_encode(array('msg' => 'La classe a été associée', 'success' => 'true'));
				return true;
			}
			echo json_encode(array('msg' => 'La classe est déjà associée', 'success' => 'false'));
			return false;
		}
	}


	/**
	 * Mettre à jour l'uid_envole dans la table ele_liste (uid_envole récupéré dans l'annuaire)
	 * lorsque l'on lance la synchro des élèves
	 * 
	 * @param array $data les informations conernant un utilisateur récupérées dans l'annuaire ldap
	 * @return void 
	 */
	function update($data = array()){
		foreach ($data as $value) {
			$req = $this->pdo->prepare('UPDATE ele_liste SET uid_envole=:uid_envole WHERE nom_ele=:nom_ele AND prenom_ele=:prenom_ele AND classe_ele=:classe_ele');
			$req->bindParam(':uid_envole', $value['uid'][0], \PDO::PARAM_STR);
			$req->bindParam(':nom_ele', $value['sn'][0], \PDO::PARAM_STR);
			$req->bindParam(':prenom_ele', $value['givenname'][0], \PDO::PARAM_STR);
			$req->bindParam(':classe_ele', $value['divcod'][0], \PDO::PARAM_STR);

			if(!$req->execute()){
				die('Erreur lors de la mise à jour. Veuillez recommencer.');
			}
		}
	}

	
	/**
	 * Ajouter dans cdt les classes ldap qui n'existent pas dans cdt
	 * 
	 * @param array $classesLdap les classes ldap
	 * @return bool retourne true si tout s'est bien passé
	 */
	function synchro($classesLdap){
		for ($i=0; $i<count($classesLdap['cn']); $i++) {
			// si la classe n'existe pas déjà dans cdt
			if(!$this->classe_exists($classesLdap['cn'][$i]) && !$this->classe_exists($classesLdap['displayname'][$i])){
				$req = $this->pdo->prepare('INSERT INTO cdt_classe (nom_classe, passe_classe, code_classe) 
					VALUES (:nom_classe, :passe_classe, :code_classe)');

				$req->bindParam(':nom_classe', $classesLdap['displayname'][$i], \PDO::PARAM_STR);
				$req->bindValue(':passe_classe', trim(md5(''), " "));
				$req->bindParam(':code_classe', $classesLdap['cn'][$i], \PDO::PARAM_STR);

				$req->execute();
			}
		}

		return true;
	}


	/**
	 * Dissocier une classe dans cdt
	 * 
	 * @param int $ID_classe l'id de la classe
	 * @return void
	 */
	function dissociate($ID_classe){
		$req = $this->pdo->prepare('UPDATE cdt_classe SET code_classe=null WHERE ID_classe=:ID_classe');
		$req->bindParam(':ID_classe', $ID_classe, \PDO::PARAM_INT);
		if(!$req->execute()){
			die('Erreur lors de la dissociation de la classe. Veuillez recommencer.');
		}
		
		echo json_encode(array('msg' => 'La classe a été dissociée'));
	}


	/**
	 * Supprimer une classe dans cdt
	 * 
	 * @param int $ID_classe l'id de la classe
	 * @return void
	 */
	function delete($ID_classe){
		$req = $this->pdo->prepare('DELETE FROM cdt_classe WHERE ID_classe=:ID_classe');
		$req->bindParam(':ID_classe', $ID_classe, \PDO::PARAM_INT);
		if(!$req->execute()){
			die('Erreur lors de la suppression de la classe. Veuillez recommencer.');
		}
		
		echo json_encode(array('msg' => 'La classe a été supprimée'));
	}


	/**
	 * Vérifier si une classe existe déjà dans cdt
	 * 
	 * @param string $code_classe    le code de la classe
	 * @return bool retourne true si la classe existe déjà
	 */
	function classe_exists($code_classe){
		$req = $this->pdo->prepare('SELECT ID_classe FROM cdt_classe WHERE code_classe=:code_classe OR (nom_classe=:code_classe AND code_classe<>"")');
		$req->bindParam(':code_classe', $code_classe, \PDO::PARAM_STR);
		$req->execute();

		if($req->rowCount() <= 0){
			return false;
		}

		return true;
	}


	/**
	 * Vérifier si un code classe existe déjà dans cdt
	 * 
	 * @param string $code_classe    le code de la classe
	 * @return bool retourne true si la classe existe déjà
	 */
	function code_classe_exists($code_classe){
		$req = $this->pdo->prepare('SELECT ID_classe FROM cdt_classe WHERE code_classe=:code_classe');
		$req->bindParam(':code_classe', $code_classe, \PDO::PARAM_STR);
		$req->execute();

		if($req->rowCount() <= 0){
			return false;
		}

		return true;
	}


	/**
	 * Vérifier si une table existe 
	 * 
	 * @param string $db la base de donnée
	 * @param string $table la table
	 * @return int  retourne true si la table existe
	 */
	function mysql_table_exists($table){
		$req = $this->pdo->prepare('SELECT TABLE_NAME FROM information_schema.tables WHERE TABLE_SCHEMA = :db AND TABLE_NAME = :table');
		$req->bindValue(':db', 'cdt');
		$req->bindValue(':table', 'ele_liste_bak');
		$req->execute();
		
		if($req->rowCount() == 0){
			return false;
		}
		return true;
	}


	/**
	 * Création de la table ele_liste_bak pour la sauvegarde des élèves qui n'existent plus dans l'annuaire
	 * 
	 * @return void
	 */
	function create_table(){
		$req = $this->pdo->prepare("CREATE TABLE `cdt`.`ele_liste_bak` (
			`id` smallint(4) unsigned NOT NULL AUTO_INCREMENT,
			`ID_ele` smallint(4) unsigned NOT NULL,
			`nom_ele` varchar(50) NOT NULL,
			`prenom_ele` varchar(50) NOT NULL,
			`classe_ele` varchar(20) NOT NULL,
			`groupe_ID_ele` smallint(4) NOT NULL DEFAULT '1',
			`groupe_ele` varchar(50) NOT NULL DEFAULT 'Classe entière',
			PRIMARY KEY (`id`)
			) ENGINE = MyISAM CHARACTER SET utf8 COLLATE utf8_general_ci");
		if(!$req->execute()){
			die('Erreur lors de la création de la table ele_liste_bak.');
		}
	}


	/**
	 * Sauvegarder les élèves qui n'existent plus dans l'annuaire
	 * 
	 * @param array $ele_notfound les élèves à sauvegarder
	 * @return void
	 */
	function backup($ele_notfound){
		// si la table ele_liste_bak n'existe pas
		if($this->mysql_table_exists('ele_liste_bak')===false){
			$this->create_table();
		}
		
		foreach ($ele_notfound as $v) {
			// on vérifie que les données n'existent pas déjà en base
			$req = $this->pdo->prepare('SELECT * from ele_liste_bak WHERE ID_ele=:ID_ele');
			$req->bindParam(':ID_ele', $v['ID_ele']);
			if(!$req->execute()){
				die('Une erreur s\'est produite. Veuillez recommencer');
			}

			if($req->rowCount() == 0){
				$upd = $this->pdo->prepare('INSERT INTO ele_liste_bak (ID_ele, nom_ele, prenom_ele, classe_ele, groupe_ID_ele, groupe_ele)
					VALUES(:ID_ele, :nom_ele, :prenom_ele, :classe_ele, :groupe_ID_ele, :groupe_ele)');
				$upd->bindParam(':ID_ele', $v['ID_ele'], \PDO::PARAM_INT);
				$upd->bindParam(':nom_ele', $v['nom_ele']);
				$upd->bindParam(':prenom_ele', $v['prenom_ele']);
				$upd->bindParam(':classe_ele', $v['classe_ele']);
				$upd->bindParam(':groupe_ID_ele', $v['groupe_ID_ele']);
				$upd->bindParam(':groupe_ele', $v['groupe_ele']);

				if(!$upd->execute()){
					die('Une erreur s\'est produite pendant la sauvegarde des élèves inexistants. Veuillez recommencer');
				}
			}
		}
	}	
}