<?php 

namespace Ldap;

class Ldap{

    private $settings;


	public function __construct($settings){
		$this->settings = $settings;
	}    

	/**
	 * Connexion à l'annuaire ldap
	 * 
	 * @return retourne une connexion au ldap
	 */
	function connect(){
		$conn = ldap_connect($this->settings['ldap_server']);
		if(!$conn){
			die('Erreur de connection à l\'annuaire');
		}

		$bind = ldap_bind($conn);
		if(!$bind){
			die('Erreur d\'authentification');
		}

		return $conn;
	}


	/**
	 * Rechercher une classe cdt dans l'annuaire ldap
	 * 
	 * @param string $search    les classes cdt à rechercher dans l'annuaire
	 * @return array $classes  les classes de l'annuaire
	 */
	function search($search = null){
		$conn = $this->connect();

		$filter = (!empty($search) && isset($search)) ? '(&(objectclass=classe)(cn='.$search.'))' : 'objectclass=classe';

		if($conn){
			$ldapsearch = ldap_search($conn, 'o=gouv,c=fr', $filter, array('cn', 'displayName'));
			if(!$ldapsearch){
				die('Erreur lors de la recherche');
			}

			$data = ldap_get_entries($conn,$ldapsearch);
			if(empty($data['count']) && $data['count']<=0){
				return false;
			}

			for ($i=0; $i < $data['count']; $i++) { 
				$classes['cn'][$i] = $data[$i]["cn"][0];
				$classes['displayname'][$i] = $data[$i]["displayname"][0];
			}

			return $classes;
		}
	}


	/**
	 * Récupérer les classes de l'annuaire ldap
	 * 
	 * @return array $classes    les classes du ldap
	 */
	function getClassesLdap(){
		return $this->search();
	}


	/**
	 * Récupérer dans ldap le code_classe des classes cdt
	 * 
	 * si code_classe est vide dans cdt
	 * on recherche dans ldap la classe
	 * dont le cn = $classes
	 * 
	 * @param array $classes    les classes dont le code_classe est vide dans cdt = nom_classe dans cdt
	 * @return bool 
	 */
	function getCodeClasse($classes){
		$data = array();
		$code_classes = array();

		foreach ($classes['nom_classe'] as $v) {
			array_push($data, $this->search($v));
		}

		for ($i=0; $i < count($data); $i++) { 
			array_push($code_classes, $data[$i]['cn'][0]);
		}

		return $code_classes;
	}
	

	/**
	 * Récupérer l'uid des élèves
	 * 
	 * @param string $sn le nom de l'élève
	 * @param string le prénom de l'élève
	 * @param string la classe de l'élève
	 * @return array retourne l'uid, le nom, prénom et la classe des utilisateurs
	 */
	function getuid($sn, $givenname, $divcod){
		$conn = $this->connect();
		$filter = '(&(objectclass=Eleves)(sn='.$sn.')(givenname='.$givenname.')(divcod='.$divcod.'))';

		$info = array();

		if($conn){
			$ldapsearch = ldap_search($conn, 'o=gouv,c=fr', $filter, array('uid', 'sn', 'givenname', 'divcod'));

			if($ldapsearch){
				$data = ldap_get_entries($conn,$ldapsearch);

				if(isset($data['count']) && $data['count']>0){
					for ($i=0; $i < $data['count']; $i++) {
						$info['uid'][$i] = $data[$i]["uid"][0];
						$info['sn'][$i] = $data[$i]["sn"][0];
						$info['givenname'][$i] = $data[$i]["givenname"][0];
						$info['divcod'][$i] = $data[$i]["divcod"][0];
					}
				}
			}
		}

		return $info;
	}
}