<?php

/**
 * script appelé lors de la synchro des élèves
 * 
 * il va chercher dans l'annuaire ldap les élèves de cdt dont l'uid_envole est vide dans la table ele_liste
 * et met à jour cette zone
 * 
 * les élèves qui n'existent pas l'annuaire sont sauvegardés dans la table ele_liste_bak
 * 
 * script appelant posh-profil/synchro/cdt-synchro.php
 */
require_once __DIR__ . '/Cdt.php';
require_once __DIR__ . '/Ldap.php';
require_once '../../cdt/inc/functions_inc.php';

$settings = require_once __DIR__ . '/settings.php';

try{
	$pdo = new PDO($settings['db.dsn'], $settings['db.username'], $settings['db.password']);
	$pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
} catch(PDOException $e){
	echo 'Connexion ?hou? : ' . $e->getMessage();
}

$ldap = new \Ldap\Ldap($settings);
$cdt = new \Cdt\Cdt($pdo);
$eleves = $cdt->getEleves();

$ele_notfound = array();	// contient la liste des élèves absents de l'annuairee

foreach ($eleves as $value) {
	// lorsque le champ uid_envole est vide va rechercher dans l'annuaire l'enregistrement où :
	// sn = nom_ele
	// givenname = prenom_ele
	// et éentuellement Divcode = classe_ele si homonymie ...
	// pour réupéer uid et le mettre dans le champ uid_envole vide.
	if($value['uid_envole'] == ''){
		// Attention à passer les champs à comparer en caractères standards (pas de majuscule, pas d'accentué)
		$nom_ele = strtolower(sans_accent($value['nom_ele']));
		$prenom_ele = strtolower(sans_accent($value['prenom_ele']));
		$divcod = strtolower(sans_accent($value['classe_ele']));

		$getuid = $ldap->getuid($nom_ele, $prenom_ele, $divcod);

		if(isset($getuid) && !empty($getuid)){
			// on met à jour l'uid
			$cdt->update($getuid);
		}
		else{
			array_push($ele_notfound,
				array(
					'ID_ele' => $value['ID_ele'],
					'prenom_ele' => $value['prenom_ele'],
					'nom_ele' => $value['nom_ele'],
					'classe_ele' => $value['classe_ele'],
					'groupe_ID_ele' => $value['groupe_ID_ele'],
					'groupe_ele' => $value['groupe_ele'],
					)
				);
		}
	}
}

// Sortir en erreur les occurrences multiples éentuelles de ldap.
if(!empty($ele_notfound) && isset($ele_notfound)){
	echo '<b>Les élèves suivants n\'ont pas été trouvés dans l\'annuaire</b><br>';
	foreach ($ele_notfound as $k => $v) {
		echo utf8_encode($v['prenom_ele']) . ' ' . utf8_encode($v['nom_ele']) . '<br>';
	}

	// on sauvegarde les élèves qui n'existent plus dans l'annuaire
	$cdt->backup($ele_notfound);
}